@@ -99,7 +99,11 @@ def _get_bullet_string(paragraph: ElementTree.Element, context: Dict[str, Any])
         numPr = pPr.find(qn("w:numPr"))
         numId = numPr.find(qn("w:numId")).attrib[qn("w:val")]
         ilvl = numPr.find(qn("w:ilvl")).attrib[qn("w:val")]
-        numFmt = context["numId2numFmts"][numId][int(ilvl)]
+        try:
+            numFmt = context["numId2numFmts"][numId][int(ilvl)]
+        except IndexError:
+            # give up and put a bullet
+            numFmt = 'bullet'
     except (AttributeError, KeyError):
         # not a numbered paragraph
         return ""
