@@ -6,9 +6,9 @@
 :created: 7/6/2019
 """
 
-from docx2python.main import get_docx_content
+from docx2python.main import docx2python
 
-INST = get_docx_content("resources/example.docx")
+INST = docx2python("resources/example.docx")
 
 
 class TestDocument:
@@ -36,6 +36,12 @@ class TestText:
         assert INST.text[:50] == (
             "\n\n\n\nHeader text----media/image1.png----\n\nI)	expect"
         )
-        assert INST.text[-50:] == (
-            "ndnote2)	\n\n Second endnote----media/image1.png----"
+        assert INST.text[-51:] == (
+            "endnote2)\t\n\n Second endnote----media/image1.png----"
         )
+
+
+class TestHtmlMap:
+    def test_function(self) -> None:
+        """Return html tables."""
+        assert INST.html_map[:49] == '<html><body><table border="1"><tr><td><pre>(0, 0,'
